@@ -49,7 +49,7 @@ _SHEEPDOG_OPTS = [
 ]
 
 
-class SheepdogImage:
+class SheepdogImage(object):
     """Class describing an image stored in Sheepdog storage."""
 
     def __init__(self, addr, port, name, chunk_size):
@@ -174,7 +174,8 @@ class ImageIterator(object):
 class Store(glance_store.driver.Store):
     """Sheepdog backend adapter."""
 
-    _CAPABILITIES = (capabilities.RW_ACCESS | capabilities.DRIVER_REUSABLE)
+    _CAPABILITIES = (capabilities.BitMasks.RW_ACCESS |
+                     capabilities.BitMasks.DRIVER_REUSABLE)
     OPTIONS = _SHEEPDOG_OPTS
     EXAMPLE_URL = "sheepdog://image"
 
