@@ -26,6 +26,8 @@ from oslo.vmware import constants
 from oslo_config import cfg
 from oslo_utils import excutils
 from oslo_utils import units
+# NOTE(jokke): simplified transition to py3, behaves like py2 xrange
+from six.moves import range
 import six.moves.urllib.parse as urlparse
 
 import glance_store
@@ -221,7 +223,8 @@ class StoreLocation(location.StoreLocation):
 class Store(glance_store.Store):
     """An implementation of the VMware datastore adapter."""
 
-    _CAPABILITIES = capabilities.BitMasks.RW_ACCESS
+    _CAPABILITIES = (capabilities.BitMasks.RW_ACCESS |
+                     capabilities.BitMasks.DRIVER_REUSABLE)
     OPTIONS = _VMWARE_OPTS
     WRITE_CHUNKSIZE = units.Mi
     # FIXME(arnaud): re-visit this code once the store API is cleaned up.
